==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QVideoFilterRunnable_shell.cpp <==
#include "QVideoFilterRunnable_shell.h"
#include <QtJambi/Cast>

void deleter_QVideoFilterRunnable(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QVideoFilterRunnable")
    QVideoFilterRunnable *_ptr = reinterpret_cast<QVideoFilterRunnable *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QVideoFilterRunnable_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QVideoFilterRunnable_shell) ); }

jmethodID QVideoFilterRunnable_shell::__shell_javaMethod(int pos) const { return QVideoFilterRunnable_shell::__shell()->javaMethod(typeid(QVideoFilterRunnable), pos); }

// emitting (writeShellConstructor)
QVideoFilterRunnable_shell::QVideoFilterRunnable_shell()
    : QVideoFilterRunnable()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QVideoFilterRunnable::QVideoFilterRunnable_shell()", QVideoFilterRunnable_shell::__shell())
    QVideoFilterRunnable_shell::__shell()->constructed(typeid(QVideoFilterRunnable));
}

// emitting (writeShellDestructor)
QVideoFilterRunnable_shell::~QVideoFilterRunnable_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QVideoFilterRunnable::~QVideoFilterRunnable()", QVideoFilterRunnable_shell::__shell())
    QVideoFilterRunnable_shell::__shell()->destructed(typeid(QVideoFilterRunnable));
}

void QVideoFilterRunnable_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QVideoFilterRunnable_shell*>(ptr)->QVideoFilterRunnable_shell::__shell()->tryDeleteShell(typeid(QVideoFilterRunnable));
}

// emitting Virtual overrides (virtualFunctions)
QVideoFrame QVideoFilterRunnable_shell::run(QVideoFrame* input0, const QVideoSurfaceFormat& surfaceFormat1, QVideoFilterRunnable::RunFlags flags2)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QVideoFilterRunnable::run(QVideoFrame*,QVideoSurfaceFormat,QVideoFilterRunnable::RunFlags)", QVideoFilterRunnable_shell::__shell())
        if(JniEnvironment __jni_env{500}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QVideoFrame  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QVideoFilterRunnable_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_input0 = qtjambi_cast<jobject>(__jni_env, input0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_input0);
                    jobject __java_surfaceFormat1 = qtjambi_cast<jobject>(__jni_env, surfaceFormat1);
                    jobject __java_flags2 = qtjambi_cast<jobject>(__jni_env, flags2);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_input0, __java_surfaceFormat1, __java_flags2);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QVideoFrame >(__jni_env, __java_return_value);
                } else {
                    QVideoFilterRunnable_shell::__shell()->warnForMethod("QVideoFilterRunnable::run(QVideoFrame*,QVideoSurfaceFormat,QVideoFilterRunnable::RunFlags)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QVideoFilterRunnable::run(QVideoFrame*,QVideoSurfaceFormat,QVideoFilterRunnable::RunFlags)");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QVideoFrame();
        }
    }else{
        return QVideoFrame();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QVideoFilterRunnable_access::__qt_run_QVideoFrame_ptr_cref_QVideoSurfaceFormat_QVideoFilterRunnable_RunFlags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID input0, QtJambiNativeID surfaceFormat1, jint flags2)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QVideoFrame* __qt_input0 = QtJambiAPI::objectFromNativeId<QVideoFrame>(input0);
    const QVideoSurfaceFormat& __qt_surfaceFormat1 = QtJambiAPI::valueReferenceFromNativeId<QVideoSurfaceFormat>(surfaceFormat1);
    QVideoFilterRunnable::RunFlags __qt_flags2 = qtjambi_cast<QVideoFilterRunnable::RunFlags>(__jni_env, flags2);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QVideoFilterRunnable::run(QVideoFrame * input, const QVideoSurfaceFormat & surfaceFormat, QVideoFilterRunnable::RunFlags flags)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QVideoFilterRunnable::run(QVideoFrame * input, const QVideoSurfaceFormat & surfaceFormat, QVideoFilterRunnable::RunFlags flags).";
    } else {
        QVideoFrame __qt_return_value = run(__qt_input0, __qt_surfaceFormat1, __qt_flags2);
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new 
void __qt_construct_QVideoFilterRunnable_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QVideoFilterRunnable *__qt_this = new(__qtjambi_ptr) QVideoFilterRunnable_shell();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QVideoFilterRunnable_shell
void __qt_destruct_QVideoFilterRunnable(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QVideoFilterRunnable")
    reinterpret_cast<QVideoFilterRunnable_shell*>(ptr)->~QVideoFilterRunnable_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QVideoFilterRunnable::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFilterRunnable_initialize_1native__Lio_qt_multimedia_QVideoFilterRunnable_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVideoFilterRunnable::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QVideoFilterRunnable_0, sizeof(QVideoFilterRunnable_shell), typeid(QVideoFilterRunnable), true, &deleter_QVideoFilterRunnable, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QVideoFilterRunnable::run(QVideoFrame*,QVideoSurfaceFormat,QVideoFilterRunnable::RunFlags)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFilterRunnable_00024ConcreteWrapper_run_1native_1QVideoFrame_1ptr_1cref_1QVideoSurfaceFormat_1QVideoFilterRunnable_1RunFlags__JJJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID input0,
 QtJambiNativeID surfaceFormat1,
 jint flags2)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QVideoFilterRunnable *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFilterRunnable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVideoFilterRunnable::run(QVideoFrame*,QVideoSurfaceFormat,QVideoFilterRunnable::RunFlags)", __qt_this)
        __java_return_value = static_cast<QVideoFilterRunnable_access*>(__qt_this)->__qt_run_QVideoFrame_ptr_cref_QVideoSurfaceFormat_QVideoFilterRunnable_RunFlags(__jni_env, __this_nativeId, input0, surfaceFormat1, flags2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QVideoFilterRunnable(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QVideoFilterRunnable>("QVideoFilterRunnable", "io/qt/multimedia/QVideoFilterRunnable");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "run", "(Lio/qt/multimedia/QVideoFrame;Lio/qt/multimedia/QVideoSurfaceFormat;Lio/qt/multimedia/QVideoFilterRunnable$RunFlags;)Lio/qt/multimedia/QVideoFrame;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QVideoFilterRunnable, {
        ConstructorInfo(&__qt_construct_QVideoFilterRunnable_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QVideoFilterRunnable);
    registerSizeOfShell(typeId, sizeof(QVideoFilterRunnable_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QVideoFilterRunnable::RunFlag>("QVideoFilterRunnable::RunFlag", "io/qt/multimedia/QVideoFilterRunnable$RunFlag", "QVideoFilterRunnable::RunFlags", "QFlags<QVideoFilterRunnable::RunFlag>", "io/qt/multimedia/QVideoFilterRunnable$RunFlags");
// END: enums and flags
}

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QVideoFilterRunnable_shell.cpp <==
#include "QVideoFilterRunnable_shell.h"
#include <QtJambi/Cast>

void deleter_QVideoFilterRunnable(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QVideoFilterRunnable")
    QVideoFilterRunnable *_ptr = reinterpret_cast<QVideoFilterRunnable *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QVideoFilterRunnable_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QVideoFilterRunnable_shell) ); }

jmethodID QVideoFilterRunnable_shell::__shell_javaMethod(int pos) const { return QVideoFilterRunnable_shell::__shell()->javaMethod(typeid(QVideoFilterRunnable), pos); }

// emitting (writeShellConstructor)
QVideoFilterRunnable_shell::QVideoFilterRunnable_shell()
    : QVideoFilterRunnable()
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QVideoFilterRunnable::QVideoFilterRunnable_shell()", QVideoFilterRunnable_shell::__shell())
    QVideoFilterRunnable_shell::__shell()->constructed(typeid(QVideoFilterRunnable));
}

// emitting (writeShellDestructor)
QVideoFilterRunnable_shell::~QVideoFilterRunnable_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QVideoFilterRunnable::~QVideoFilterRunnable()", QVideoFilterRunnable_shell::__shell())
    QVideoFilterRunnable_shell::__shell()->destructed(typeid(QVideoFilterRunnable));
}

void QVideoFilterRunnable_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QVideoFilterRunnable_shell*>(ptr)->QVideoFilterRunnable_shell::__shell()->tryDeleteShell(typeid(QVideoFilterRunnable));
}

// emitting Virtual overrides (virtualFunctions)
QVideoFrame QVideoFilterRunnable_shell::run(QVideoFrame* input0, const QVideoSurfaceFormat& surfaceFormat1, QVideoFilterRunnable::RunFlags flags2)
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QVideoFilterRunnable::run(QVideoFrame*,QVideoSurfaceFormat,QVideoFilterRunnable::RunFlags)", QVideoFilterRunnable_shell::__shell())
        if(JniEnvironment __jni_env{500}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QVideoFrame  __qt_return_value;
            QTJAMBI_TRY {
                if(jobject __java_this = QVideoFilterRunnable_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_input0 = qtjambi_cast<jobject>(__jni_env, input0);
                    QTJAMBI_INVALIDATE_AFTER_USE(__jni_env, __java_input0);
                    jobject __java_surfaceFormat1 = qtjambi_cast<jobject>(__jni_env, surfaceFormat1);
                    jobject __java_flags2 = qtjambi_cast<jobject>(__jni_env, flags2);
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id, __java_input0, __java_surfaceFormat1, __java_flags2);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QVideoFrame >(__jni_env, __java_return_value);
                } else {
                    QVideoFilterRunnable_shell::__shell()->warnForMethod("QVideoFilterRunnable::run(QVideoFrame*,QVideoSurfaceFormat,QVideoFilterRunnable::RunFlags)");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QVideoFilterRunnable::run(QVideoFrame*,QVideoSurfaceFormat,QVideoFilterRunnable::RunFlags)");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QVideoFrame();
        }
    }else{
        return QVideoFrame();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
jobject QVideoFilterRunnable_access::__qt_run_QVideoFrame_ptr_cref_QVideoSurfaceFormat_QVideoFilterRunnable_RunFlags(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID input0, QtJambiNativeID surfaceFormat1, jint flags2)
{
    Q_UNUSED(__jni_env)
    Q_ASSERT(!!__this_nativeId);
    QVideoFrame* __qt_input0 = QtJambiAPI::objectFromNativeId<QVideoFrame>(input0);
    const QVideoSurfaceFormat& __qt_surfaceFormat1 = QtJambiAPI::valueReferenceFromNativeId<QVideoSurfaceFormat>(surfaceFormat1);
    QVideoFilterRunnable::RunFlags __qt_flags2 = qtjambi_cast<QVideoFilterRunnable::RunFlags>(__jni_env, flags2);
    if (QtJambiAPI::isShell(__this_nativeId)) {
        JavaException::raiseQNoImplementationException(__jni_env, "Call of pure virtual method QVideoFilterRunnable::run(QVideoFrame * input, const QVideoSurfaceFormat & surfaceFormat, QVideoFilterRunnable::RunFlags flags)." QTJAMBI_STACKTRACEINFO );
        throw "Call of pure virtual method QVideoFilterRunnable::run(QVideoFrame * input, const QVideoSurfaceFormat & surfaceFormat, QVideoFilterRunnable::RunFlags flags).";
    } else {
        QVideoFrame __qt_return_value = run(__qt_input0, __qt_surfaceFormat1, __qt_flags2);
        return qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }
}

// emitting (writeConstructors)
// new QVideoFilterRunnable()
void __qt_construct_QVideoFilterRunnable(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QVideoFilterRunnable()")
    Q_UNUSED(__java_arguments)
    QVideoFilterRunnable *__qt_this = new(__qtjambi_ptr) QVideoFilterRunnable_shell();
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// QVideoFilterRunnable::QVideoFilterRunnable()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFilterRunnable_initialize_1native__Lio_qt_multimedia_QVideoFilterRunnable_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QVideoFilterRunnable::QVideoFilterRunnable()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QVideoFilterRunnable, sizeof(QVideoFilterRunnable_shell), typeid(QVideoFilterRunnable), true, &deleter_QVideoFilterRunnable, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QVideoFilterRunnable_shell
void __qt_destruct_QVideoFilterRunnable(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QVideoFilterRunnable")
    reinterpret_cast<QVideoFilterRunnable_shell*>(ptr)->~QVideoFilterRunnable_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QVideoFilterRunnable::run(QVideoFrame*,QVideoSurfaceFormat,QVideoFilterRunnable::RunFlags)
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QVideoFilterRunnable_00024ConcreteWrapper_run_1native_1QVideoFrame_1ptr_1cref_1QVideoSurfaceFormat_1QVideoFilterRunnable_1RunFlags__JJJI)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID input0,
 QtJambiNativeID surfaceFormat1,
 jint flags2)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QVideoFilterRunnable *__qt_this = QtJambiAPI::objectFromNativeId<QVideoFilterRunnable>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QVideoFilterRunnable::run(QVideoFrame*,QVideoSurfaceFormat,QVideoFilterRunnable::RunFlags)", __qt_this)
        __java_return_value = static_cast<QVideoFilterRunnable_access*>(__qt_this)->__qt_run_QVideoFrame_ptr_cref_QVideoSurfaceFormat_QVideoFilterRunnable_RunFlags(__jni_env, __this_nativeId, input0, surfaceFormat1, flags2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QVideoFilterRunnable(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QVideoFilterRunnable>("QVideoFilterRunnable", "io/qt/multimedia/QVideoFilterRunnable");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "run", "(Lio/qt/multimedia/QVideoFrame;Lio/qt/multimedia/QVideoSurfaceFormat;Lio/qt/multimedia/QVideoFilterRunnable$RunFlags;)Lio/qt/multimedia/QVideoFrame;", FunctionInfo::Abstract)});
    registerConstructorInfos(typeId, &__qt_destruct_QVideoFilterRunnable, {
        ConstructorInfo(&__qt_construct_QVideoFilterRunnable, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QVideoFilterRunnable);
    registerSizeOfShell(typeId, sizeof(QVideoFilterRunnable_shell));
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QVideoFilterRunnable::RunFlag>("QVideoFilterRunnable::RunFlag", "io/qt/multimedia/QVideoFilterRunnable$RunFlag", "QVideoFilterRunnable::RunFlags", "QFlags<QVideoFilterRunnable::RunFlag>", "io/qt/multimedia/QVideoFilterRunnable$RunFlags");
// END: enums and flags
}
